@@ -212,8 +212,8 @@ search_equal_func(GtkTreeModel *model,
                        COL_USER, &user,
                        -1);
 
-    found = !((name && strstr(name, key))
-              || (user && strstr(user, key)));
+    found = !((name && strcasestr(name, key))
+              || (user && strcasestr(user, key)));
 
     g_free(name);
     g_free(user);
@@ -255,6 +255,8 @@ proctable_new (ProcData * const procdata)
         N_("Control Group"),
         N_("Unit"),
         N_("Session"),
+        /* TRANSLATORS: Seat = i.e. the physical seat the session of the process belongs to, only
+	for multi-seat environments. See http://en.wikipedia.org/wiki/Multiseat_configuration */
         N_("Seat"),
         N_("Owner"),
         N_("Priority"),
@@ -677,7 +679,12 @@ insert_info_to_tree (ProcInfo *info, ProcData *procdata, bool forced = false)
             GtkTreePath *parent_node = gtk_tree_model_get_path(model, &parent->node);
             gtk_tree_store_insert(GTK_TREE_STORE(model), &info->node, &parent->node, 0);
 
-            if (!gtk_tree_view_row_expanded(GTK_TREE_VIEW(procdata->tree), parent_node))
+            if (!gtk_tree_view_row_expanded(GTK_TREE_VIEW(procdata->tree), parent_node)
+#ifdef __linux__
+                // on linuxes we don't want to expand kthreadd by default (always has pid 2)
+                && (parent->pid != 2)
+#endif
+            )
                 gtk_tree_view_expand_row(GTK_TREE_VIEW(procdata->tree), parent_node, FALSE);
             gtk_tree_path_free(parent_node);
         } else
